@@ -48,15 +48,17 @@ def blog_post_list(request, tag=None, year=None, month=None, username=None,
     # without triggering "num posts x 2" queries.
     #
     # For Django 1.3 we create dicts mapping blog post IDs to lists of
-    # categories and keywords, and assign these to each blog post
-    #
-    # For Django 1.4 we just use prefetch related.
+    # categories and keywords, and assign these to attributes on each
+    # blog post. The Blog model then uses accessor methods to retrieve
+    # these attributes when assigned, which will fall back to the real
+    # related managers for Django 1.4 and higher, which will already
+    # have their data retrieved via prefetch_related.
 
+    blog_posts = blog_posts.select_related("user")
     if VERSION >= (1, 4):
-        rel = ("categories", "keywords__keyword")
-        blog_posts = blog_posts.select_related("user").prefetch_related(*rel)
+        blog_posts = blog_posts.prefetch_related("categories",
+                                                 "keywords__keyword")
     else:
-        blog_posts = list(blog_posts.select_related("user"))
         categories = defaultdict(list)
         if blog_posts:
             ids = ",".join([str(p.id) for p in blog_posts])
@@ -73,18 +75,11 @@ def blog_post_list(request, tag=None, year=None, month=None, username=None,
                         content_type=blogpost_type).select_related("keyword")
         for a in assigned:
             keywords[a.object_pk].append(a.keyword)
-    for i, post in enumerate(blog_posts):
-        if VERSION < (1, 4):
-            setattr(blog_posts[i], "category_list", categories[post.id])
-            setattr(blog_posts[i], "keyword_list", keywords[post.id])
-        else:
-            setattr(blog_posts[i], "category_list",
-                    post.categories.all())
-            setattr(blog_posts[i], "keyword_list",
-                    [k.keyword for k in post.keywords.all()])
+        for i, post in enumerate(blog_posts):
+            setattr(blog_posts[i], "_categories", categories[post.id])
+            setattr(blog_posts[i], "_keywords", keywords[post.id])
 
-    blog_posts = paginate(blog_posts,
-                          request.GET.get("page", 1),
+    blog_posts = paginate(blog_posts, request.GET.get("page", 1),
                           settings.BLOG_POST_PER_PAGE,
                           settings.MAX_PAGING_LINKS)
     context = {"blog_posts": blog_posts, "year": year, "month": month,
@@ -101,7 +96,7 @@ def blog_post_detail(request, slug, year=None, month=None, day=None,
     """
     blog_posts = BlogPost.objects.published(for_user=request.user)
     blog_post = get_object_or_404(blog_posts, slug=slug)
-    context = {"blog_post": blog_post}
+    context = {"blog_post": blog_post, "editable_obj": blog_post}
     templates = [u"blog/blog_post_detail_%s.html" % unicode(slug), template]
     return render(request, templates, context)
 
