@@ -4,7 +4,7 @@ from copy import copy
 from django.conf import settings
 from django.contrib.contenttypes.generic import GenericRelation
 from django.core.exceptions import ImproperlyConfigured
-from django.db.models import IntegerField, CharField, FloatField
+from django.db.models import get_model, IntegerField, CharField, FloatField
 from django.db.models.signals import post_save, post_delete
 
 
@@ -53,11 +53,9 @@ class BaseGenericRelation(GenericRelation):
                     name, field.name)
                 raise ImproperlyConfigured(e)
         self.related_field_name = name
-        if self.frozen_by_south:
-            return
         super(BaseGenericRelation, self).contribute_to_class(cls, name)
         # Not applicable to abstract classes, and in fact will break.
-        if not cls._meta.abstract:
+        if not cls._meta.abstract and not self.frozen_by_south:
             for (name_string, field) in self.fields.items():
                 if "%s" in name_string:
                     name_string = name_string % name
@@ -80,7 +78,12 @@ class BaseGenericRelation(GenericRelation):
         """
         # Manually check that the instance matches the relation,
         # since we don't specify a sender for the signal.
-        if not isinstance(kwargs["instance"], self.rel.to):
+        try:
+            to = self.rel.to
+            if isinstance(to, basestring):
+                to = get_model(*to.split(".", 1))
+            assert isinstance(kwargs["instance"], to)
+        except (TypeError, ValueError, AssertionError):
             return
         for_model = kwargs["instance"].content_type.model_class()
         if issubclass(for_model, self.model):
@@ -249,4 +252,3 @@ if "south" in settings.INSTALLED_APPS:
             patterns=["mezzanine\.generic\.fields\."])
     except ImportError:
         pass
-
