@@ -2,7 +2,7 @@
 import re
 import unicodedata
 
-from django.core.urlresolvers import reverse, NoReverseMatch
+from django.core.urlresolvers import resolve, reverse, NoReverseMatch
 from django.shortcuts import redirect
 from django.utils.encoding import smart_unicode
 
@@ -22,6 +22,19 @@ def admin_url(model, url, object_id=None):
     return reverse(url, args=args)
 
 
+def home_slug():
+    """
+    Returns the slug arg defined for the ``home`` urlpattern, which
+    is the definitive source of the ``url`` field defined for an
+    editable homepage object.
+    """
+    slug = reverse("home")
+    try:
+        return resolve(slug).kwargs["slug"]
+    except KeyError:
+        return slug
+
+
 def slugify(s):
     """
     Loads the callable defined by the ``SLUGIFY`` setting, which defaults
